@@ -28,14 +28,14 @@ class Sequential(object):
     def __getstate__(self):
         state = self.__dict__.copy()
 
-        with tempfile.NamedTemporaryFile(suffix='.hdf5', delete=True) as fd:
+        with tempfile.NamedTemporaryFile(suffix='.hdf5', delete=False) as fd:
             keras.models.save_model(state.pop('model'), fd.name, overwrite=True)
             state['model_str'] = fd.read()
 
         return state
 
     def __setstate__(self, state):
-        with tempfile.NamedTemporaryFile(suffix='.hdf5', delete=True) as fd:
+        with tempfile.NamedTemporaryFile(suffix='.hdf5', delete=False) as fd:
             fd.write(state.pop('model_str'))
             fd.flush()
 
@@ -72,6 +72,7 @@ class Sequential(object):
         self.validation_split = validation_split
         self.batch_size = batch_size
         self.shuffle = shuffle
+        self._fitted = False
 
         for callback in callbacks:
             callback['class'] = import_object(callback['class'])
@@ -85,18 +86,24 @@ class Sequential(object):
         if key in self.hyperparameters and self.hyperparameters[key] is None:
             kwargs[key] = value
 
-    def _augment_hyperparameters(self, X, kwargs):
+    def _augment_hyperparameters(self, X, mode, kwargs):
         shape = np.asarray(X)[0].shape
-        length = shape[0]
-        self._setdefault(kwargs, 'input_shape', shape)
-        self._setdefault(kwargs, 'input_dim', length)
-        self._setdefault(kwargs, 'input_length', length)
+        if shape:
+            length = shape[0]
+        else:
+            length = 1  # supporting shape (l, )
+
+        self._setdefault(kwargs, '{}_shape'.format(mode), shape)
+        self._setdefault(kwargs, '{}_dim'.format(mode), length)
+        self._setdefault(kwargs, '{}_length'.format(mode), length)
 
         return kwargs
 
     def fit(self, X, y, **kwargs):
-        self._augment_hyperparameters(X, kwargs)
-        self.model = self._build_model(**kwargs)
+        if not self._fitted:
+            self._augment_hyperparameters(X, 'input', kwargs)
+            self._augment_hyperparameters(y, 'target', kwargs)
+            self.model = self._build_model(**kwargs)
 
         if self.classification:
             y = keras.utils.to_categorical(y)
@@ -110,6 +117,8 @@ class Sequential(object):
                        validation_split=self.validation_split, batch_size=self.batch_size,
                        shuffle=self.shuffle)
 
+        self._fitted = True
+
     def predict(self, X):
         y = self.model.predict(X, batch_size=self.batch_size, verbose=self.verbose)
 
